import { _ScheduleActivityTaskDecisionAttributes, _UnmarshalledScheduleActivityTaskDecisionAttributes } from "./_ScheduleActivityTaskDecisionAttributes";
import { _RequestCancelActivityTaskDecisionAttributes, _UnmarshalledRequestCancelActivityTaskDecisionAttributes } from "./_RequestCancelActivityTaskDecisionAttributes";
import { _CompleteWorkflowExecutionDecisionAttributes, _UnmarshalledCompleteWorkflowExecutionDecisionAttributes } from "./_CompleteWorkflowExecutionDecisionAttributes";
import { _FailWorkflowExecutionDecisionAttributes, _UnmarshalledFailWorkflowExecutionDecisionAttributes } from "./_FailWorkflowExecutionDecisionAttributes";
import { _CancelWorkflowExecutionDecisionAttributes, _UnmarshalledCancelWorkflowExecutionDecisionAttributes } from "./_CancelWorkflowExecutionDecisionAttributes";
import { _ContinueAsNewWorkflowExecutionDecisionAttributes, _UnmarshalledContinueAsNewWorkflowExecutionDecisionAttributes } from "./_ContinueAsNewWorkflowExecutionDecisionAttributes";
import { _RecordMarkerDecisionAttributes, _UnmarshalledRecordMarkerDecisionAttributes } from "./_RecordMarkerDecisionAttributes";
import { _StartTimerDecisionAttributes, _UnmarshalledStartTimerDecisionAttributes } from "./_StartTimerDecisionAttributes";
import { _CancelTimerDecisionAttributes, _UnmarshalledCancelTimerDecisionAttributes } from "./_CancelTimerDecisionAttributes";
import { _SignalExternalWorkflowExecutionDecisionAttributes, _UnmarshalledSignalExternalWorkflowExecutionDecisionAttributes } from "./_SignalExternalWorkflowExecutionDecisionAttributes";
import { _RequestCancelExternalWorkflowExecutionDecisionAttributes, _UnmarshalledRequestCancelExternalWorkflowExecutionDecisionAttributes } from "./_RequestCancelExternalWorkflowExecutionDecisionAttributes";
import { _StartChildWorkflowExecutionDecisionAttributes, _UnmarshalledStartChildWorkflowExecutionDecisionAttributes } from "./_StartChildWorkflowExecutionDecisionAttributes";
import { _ScheduleLambdaFunctionDecisionAttributes, _UnmarshalledScheduleLambdaFunctionDecisionAttributes } from "./_ScheduleLambdaFunctionDecisionAttributes";
/**
 * <p>Specifies a decision made by the decider. A decision can be one of these types:</p> <ul> <li> <p> <code>CancelTimer</code> – Cancels a previously started timer and records a <code>TimerCanceled</code> event in the history.</p> </li> <li> <p> <code>CancelWorkflowExecution</code> – Closes the workflow execution and records a <code>WorkflowExecutionCanceled</code> event in the history.</p> </li> <li> <p> <code>CompleteWorkflowExecution</code> – Closes the workflow execution and records a <code>WorkflowExecutionCompleted</code> event in the history .</p> </li> <li> <p> <code>ContinueAsNewWorkflowExecution</code> – Closes the workflow execution and starts a new workflow execution of the same type using the same workflow ID and a unique run Id. A <code>WorkflowExecutionContinuedAsNew</code> event is recorded in the history.</p> </li> <li> <p> <code>FailWorkflowExecution</code> – Closes the workflow execution and records a <code>WorkflowExecutionFailed</code> event in the history.</p> </li> <li> <p> <code>RecordMarker</code> – Records a <code>MarkerRecorded</code> event in the history. Markers can be used for adding custom information in the history for instance to let deciders know that they don't need to look at the history beyond the marker event.</p> </li> <li> <p> <code>RequestCancelActivityTask</code> – Attempts to cancel a previously scheduled activity task. If the activity task was scheduled but has not been assigned to a worker, then it is canceled. If the activity task was already assigned to a worker, then the worker is informed that cancellation has been requested in the response to <a>RecordActivityTaskHeartbeat</a>.</p> </li> <li> <p> <code>RequestCancelExternalWorkflowExecution</code> – Requests that a request be made to cancel the specified external workflow execution and records a <code>RequestCancelExternalWorkflowExecutionInitiated</code> event in the history.</p> </li> <li> <p> <code>ScheduleActivityTask</code> – Schedules an activity task.</p> </li> <li> <p> <code>SignalExternalWorkflowExecution</code> – Requests a signal to be delivered to the specified external workflow execution and records a <code>SignalExternalWorkflowExecutionInitiated</code> event in the history.</p> </li> <li> <p> <code>StartChildWorkflowExecution</code> – Requests that a child workflow execution be started and records a <code>StartChildWorkflowExecutionInitiated</code> event in the history. The child workflow execution is a separate workflow execution with its own history.</p> </li> <li> <p> <code>StartTimer</code> – Starts a timer for this workflow execution and records a <code>TimerStarted</code> event in the history. This timer fires after the specified delay and record a <code>TimerFired</code> event.</p> </li> </ul> <p> <b>Access Control</b> </p> <p>If you grant permission to use <code>RespondDecisionTaskCompleted</code>, you can use IAM policies to express permissions for the list of decisions returned by this action as if they were members of the API. Treating decisions as a pseudo API maintains a uniform conceptual model and helps keep policies readable. For details and example IAM policies, see <a href="https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html">Using IAM to Manage Access to Amazon SWF Workflows</a> in the <i>Amazon SWF Developer Guide</i>.</p> <p> <b>Decision Failure</b> </p> <p>Decisions can fail for several reasons</p> <ul> <li> <p>The ordering of decisions should follow a logical flow. Some decisions might not make sense in the current context of the workflow execution and therefore fails.</p> </li> <li> <p>A limit on your account was reached.</p> </li> <li> <p>The decision lacks sufficient permissions.</p> </li> </ul> <p>One of the following events might be added to the history to indicate an error. The event attribute's <code>cause</code> parameter indicates the cause. If <code>cause</code> is set to <code>OPERATION_NOT_PERMITTED</code>, the decision failed because it lacked sufficient permissions. For details and example IAM policies, see <a href="https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html">Using IAM to Manage Access to Amazon SWF Workflows</a> in the <i>Amazon SWF Developer Guide</i>.</p> <ul> <li> <p> <code>ScheduleActivityTaskFailed</code> – A <code>ScheduleActivityTask</code> decision failed. This could happen if the activity type specified in the decision isn't registered, is in a deprecated state, or the decision isn't properly configured.</p> </li> <li> <p> <code>RequestCancelActivityTaskFailed</code> – A <code>RequestCancelActivityTask</code> decision failed. This could happen if there is no open activity task with the specified activityId.</p> </li> <li> <p> <code>StartTimerFailed</code> – A <code>StartTimer</code> decision failed. This could happen if there is another open timer with the same timerId.</p> </li> <li> <p> <code>CancelTimerFailed</code> – A <code>CancelTimer</code> decision failed. This could happen if there is no open timer with the specified timerId.</p> </li> <li> <p> <code>StartChildWorkflowExecutionFailed</code> – A <code>StartChildWorkflowExecution</code> decision failed. This could happen if the workflow type specified isn't registered, is deprecated, or the decision isn't properly configured.</p> </li> <li> <p> <code>SignalExternalWorkflowExecutionFailed</code> – A <code>SignalExternalWorkflowExecution</code> decision failed. This could happen if the <code>workflowID</code> specified in the decision was incorrect.</p> </li> <li> <p> <code>RequestCancelExternalWorkflowExecutionFailed</code> – A <code>RequestCancelExternalWorkflowExecution</code> decision failed. This could happen if the <code>workflowID</code> specified in the decision was incorrect.</p> </li> <li> <p> <code>CancelWorkflowExecutionFailed</code> – A <code>CancelWorkflowExecution</code> decision failed. This could happen if there is an unhandled decision task pending in the workflow execution.</p> </li> <li> <p> <code>CompleteWorkflowExecutionFailed</code> – A <code>CompleteWorkflowExecution</code> decision failed. This could happen if there is an unhandled decision task pending in the workflow execution.</p> </li> <li> <p> <code>ContinueAsNewWorkflowExecutionFailed</code> – A <code>ContinueAsNewWorkflowExecution</code> decision failed. This could happen if there is an unhandled decision task pending in the workflow execution or the ContinueAsNewWorkflowExecution decision was not configured correctly.</p> </li> <li> <p> <code>FailWorkflowExecutionFailed</code> – A <code>FailWorkflowExecution</code> decision failed. This could happen if there is an unhandled decision task pending in the workflow execution.</p> </li> </ul> <p>The preceding error events might occur due to an error in the decider logic, which might put the workflow execution in an unstable state The cause field in the event structure for the error event indicates the cause of the error.</p> <note> <p>A workflow execution may be closed by the decider by returning one of the following decisions when completing a decision task: <code>CompleteWorkflowExecution</code>, <code>FailWorkflowExecution</code>, <code>CancelWorkflowExecution</code> and <code>ContinueAsNewWorkflowExecution</code>. An <code>UnhandledDecision</code> fault is returned if a workflow closing decision is specified and a signal or activity event had been added to the history while the decision task was being performed by the decider. Unlike the above situations which are logic issues, this fault is always possible because of race conditions in a distributed system. The right action here is to call <a>RespondDecisionTaskCompleted</a> without any decisions. This would result in another decision task with these new events included in the history. The decider should handle the new events and may decide to close the workflow execution.</p> </note> <p> <b>How to Code a Decision</b> </p> <p>You code a decision by first setting the decision type field to one of the above decision values, and then set the corresponding attributes field shown below:</p> <ul> <li> <p> <code> <a>ScheduleActivityTaskDecisionAttributes</a> </code> </p> </li> <li> <p> <code> <a>RequestCancelActivityTaskDecisionAttributes</a> </code> </p> </li> <li> <p> <code> <a>CompleteWorkflowExecutionDecisionAttributes</a> </code> </p> </li> <li> <p> <code> <a>FailWorkflowExecutionDecisionAttributes</a> </code> </p> </li> <li> <p> <code> <a>CancelWorkflowExecutionDecisionAttributes</a> </code> </p> </li> <li> <p> <code> <a>ContinueAsNewWorkflowExecutionDecisionAttributes</a> </code> </p> </li> <li> <p> <code> <a>RecordMarkerDecisionAttributes</a> </code> </p> </li> <li> <p> <code> <a>StartTimerDecisionAttributes</a> </code> </p> </li> <li> <p> <code> <a>CancelTimerDecisionAttributes</a> </code> </p> </li> <li> <p> <code> <a>SignalExternalWorkflowExecutionDecisionAttributes</a> </code> </p> </li> <li> <p> <code> <a>RequestCancelExternalWorkflowExecutionDecisionAttributes</a> </code> </p> </li> <li> <p> <code> <a>StartChildWorkflowExecutionDecisionAttributes</a> </code> </p> </li> </ul>
 */
export interface _Decision {
    /**
     * <p>Specifies the type of the decision.</p>
     */
    decisionType: "ScheduleActivityTask" | "RequestCancelActivityTask" | "CompleteWorkflowExecution" | "FailWorkflowExecution" | "CancelWorkflowExecution" | "ContinueAsNewWorkflowExecution" | "RecordMarker" | "StartTimer" | "CancelTimer" | "SignalExternalWorkflowExecution" | "RequestCancelExternalWorkflowExecution" | "StartChildWorkflowExecution" | "ScheduleLambdaFunction" | string;
    /**
     * <p>Provides the details of the <code>ScheduleActivityTask</code> decision. It isn't set for other decision types.</p>
     */
    scheduleActivityTaskDecisionAttributes?: _ScheduleActivityTaskDecisionAttributes;
    /**
     * <p>Provides the details of the <code>RequestCancelActivityTask</code> decision. It isn't set for other decision types.</p>
     */
    requestCancelActivityTaskDecisionAttributes?: _RequestCancelActivityTaskDecisionAttributes;
    /**
     * <p>Provides the details of the <code>CompleteWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    completeWorkflowExecutionDecisionAttributes?: _CompleteWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>FailWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    failWorkflowExecutionDecisionAttributes?: _FailWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>CancelWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    cancelWorkflowExecutionDecisionAttributes?: _CancelWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>ContinueAsNewWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    continueAsNewWorkflowExecutionDecisionAttributes?: _ContinueAsNewWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>RecordMarker</code> decision. It isn't set for other decision types.</p>
     */
    recordMarkerDecisionAttributes?: _RecordMarkerDecisionAttributes;
    /**
     * <p>Provides the details of the <code>StartTimer</code> decision. It isn't set for other decision types.</p>
     */
    startTimerDecisionAttributes?: _StartTimerDecisionAttributes;
    /**
     * <p>Provides the details of the <code>CancelTimer</code> decision. It isn't set for other decision types.</p>
     */
    cancelTimerDecisionAttributes?: _CancelTimerDecisionAttributes;
    /**
     * <p>Provides the details of the <code>SignalExternalWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    signalExternalWorkflowExecutionDecisionAttributes?: _SignalExternalWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>RequestCancelExternalWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    requestCancelExternalWorkflowExecutionDecisionAttributes?: _RequestCancelExternalWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>StartChildWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    startChildWorkflowExecutionDecisionAttributes?: _StartChildWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>ScheduleLambdaFunction</code> decision. It isn't set for other decision types.</p>
     */
    scheduleLambdaFunctionDecisionAttributes?: _ScheduleLambdaFunctionDecisionAttributes;
}
export interface _UnmarshalledDecision extends _Decision {
    /**
     * <p>Provides the details of the <code>ScheduleActivityTask</code> decision. It isn't set for other decision types.</p>
     */
    scheduleActivityTaskDecisionAttributes?: _UnmarshalledScheduleActivityTaskDecisionAttributes;
    /**
     * <p>Provides the details of the <code>RequestCancelActivityTask</code> decision. It isn't set for other decision types.</p>
     */
    requestCancelActivityTaskDecisionAttributes?: _UnmarshalledRequestCancelActivityTaskDecisionAttributes;
    /**
     * <p>Provides the details of the <code>CompleteWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    completeWorkflowExecutionDecisionAttributes?: _UnmarshalledCompleteWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>FailWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    failWorkflowExecutionDecisionAttributes?: _UnmarshalledFailWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>CancelWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    cancelWorkflowExecutionDecisionAttributes?: _UnmarshalledCancelWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>ContinueAsNewWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    continueAsNewWorkflowExecutionDecisionAttributes?: _UnmarshalledContinueAsNewWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>RecordMarker</code> decision. It isn't set for other decision types.</p>
     */
    recordMarkerDecisionAttributes?: _UnmarshalledRecordMarkerDecisionAttributes;
    /**
     * <p>Provides the details of the <code>StartTimer</code> decision. It isn't set for other decision types.</p>
     */
    startTimerDecisionAttributes?: _UnmarshalledStartTimerDecisionAttributes;
    /**
     * <p>Provides the details of the <code>CancelTimer</code> decision. It isn't set for other decision types.</p>
     */
    cancelTimerDecisionAttributes?: _UnmarshalledCancelTimerDecisionAttributes;
    /**
     * <p>Provides the details of the <code>SignalExternalWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    signalExternalWorkflowExecutionDecisionAttributes?: _UnmarshalledSignalExternalWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>RequestCancelExternalWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    requestCancelExternalWorkflowExecutionDecisionAttributes?: _UnmarshalledRequestCancelExternalWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>StartChildWorkflowExecution</code> decision. It isn't set for other decision types.</p>
     */
    startChildWorkflowExecutionDecisionAttributes?: _UnmarshalledStartChildWorkflowExecutionDecisionAttributes;
    /**
     * <p>Provides the details of the <code>ScheduleLambdaFunction</code> decision. It isn't set for other decision types.</p>
     */
    scheduleLambdaFunctionDecisionAttributes?: _UnmarshalledScheduleLambdaFunctionDecisionAttributes;
}
