import { _ActivityType, _UnmarshalledActivityType } from "./_ActivityType";
/**
 * <p>Provides the details of the <code>ScheduleActivityTaskFailed</code> event.</p>
 */
export interface _ScheduleActivityTaskFailedEventAttributes {
    /**
     * <p>The activity type provided in the <code>ScheduleActivityTask</code> decision that failed.</p>
     */
    activityType: _ActivityType;
    /**
     * <p>The activityId provided in the <code>ScheduleActivityTask</code> decision that failed.</p>
     */
    activityId: string;
    /**
     * <p>The cause of the failure. This information is generated by the system and can be useful for diagnostic purposes.</p> <note> <p>If <code>cause</code> is set to <code>OPERATION_NOT_PERMITTED</code>, the decision failed because it lacked sufficient permissions. For details and example IAM policies, see <a href="https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html">Using IAM to Manage Access to Amazon SWF Workflows</a> in the <i>Amazon SWF Developer Guide</i>.</p> </note>
     */
    cause: "ACTIVITY_TYPE_DEPRECATED" | "ACTIVITY_TYPE_DOES_NOT_EXIST" | "ACTIVITY_ID_ALREADY_IN_USE" | "OPEN_ACTIVITIES_LIMIT_EXCEEDED" | "ACTIVITY_CREATION_RATE_EXCEEDED" | "DEFAULT_SCHEDULE_TO_CLOSE_TIMEOUT_UNDEFINED" | "DEFAULT_TASK_LIST_UNDEFINED" | "DEFAULT_SCHEDULE_TO_START_TIMEOUT_UNDEFINED" | "DEFAULT_START_TO_CLOSE_TIMEOUT_UNDEFINED" | "DEFAULT_HEARTBEAT_TIMEOUT_UNDEFINED" | "OPERATION_NOT_PERMITTED" | string;
    /**
     * <p>The ID of the <code>DecisionTaskCompleted</code> event corresponding to the decision that resulted in the scheduling of this activity task. This information can be useful for diagnosing problems by tracing back the chain of events leading up to this event.</p>
     */
    decisionTaskCompletedEventId: number;
}
export interface _UnmarshalledScheduleActivityTaskFailedEventAttributes extends _ScheduleActivityTaskFailedEventAttributes {
    /**
     * <p>The activity type provided in the <code>ScheduleActivityTask</code> decision that failed.</p>
     */
    activityType: _UnmarshalledActivityType;
}
