/**
 * <p>Provides the details of the <code>SignalExternalWorkflowExecutionFailed</code> event.</p>
 */
export interface _SignalExternalWorkflowExecutionFailedEventAttributes {
    /**
     * <p>The <code>workflowId</code> of the external workflow execution that the signal was being delivered to.</p>
     */
    workflowId: string;
    /**
     * <p>The <code>runId</code> of the external workflow execution that the signal was being delivered to.</p>
     */
    runId?: string;
    /**
     * <p>The cause of the failure. This information is generated by the system and can be useful for diagnostic purposes.</p> <note> <p>If <code>cause</code> is set to <code>OPERATION_NOT_PERMITTED</code>, the decision failed because it lacked sufficient permissions. For details and example IAM policies, see <a href="https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html">Using IAM to Manage Access to Amazon SWF Workflows</a> in the <i>Amazon SWF Developer Guide</i>.</p> </note>
     */
    cause: "UNKNOWN_EXTERNAL_WORKFLOW_EXECUTION" | "SIGNAL_EXTERNAL_WORKFLOW_EXECUTION_RATE_EXCEEDED" | "OPERATION_NOT_PERMITTED" | string;
    /**
     * <p>The ID of the <code>SignalExternalWorkflowExecutionInitiated</code> event corresponding to the <code>SignalExternalWorkflowExecution</code> decision to request this signal. This information can be useful for diagnosing problems by tracing back the chain of events leading up to this event.</p>
     */
    initiatedEventId: number;
    /**
     * <p>The ID of the <code>DecisionTaskCompleted</code> event corresponding to the decision task that resulted in the <code>SignalExternalWorkflowExecution</code> decision for this signal. This information can be useful for diagnosing problems by tracing back the chain of events leading up to this event.</p>
     */
    decisionTaskCompletedEventId: number;
    /**
     * <p>The data attached to the event that the decider can use in subsequent workflow tasks. This data isn't sent to the workflow execution.</p>
     */
    control?: string;
}
export declare type _UnmarshalledSignalExternalWorkflowExecutionFailedEventAttributes = _SignalExternalWorkflowExecutionFailedEventAttributes;
